NvTiffStatusError

Enum NvTiffStatusError 

#[non_exhaustive]
pub enum NvTiffStatusError {
Show 15 variants NotInitialized, InvalidParameter, BadTiff, TiffNotSupported, AllocatorFailure, ExecutionFailed, ArchMismatch, InternalError, NvcompNotFound, NvjpegNotFound, TagNotFound, ParameterOutOfBounds, Nvjpeg2kNotFound, BatchIncompatible, Other(u32),
}
nvTIFF Decode API non-zero return status codes

Based on https://docs.nvidia.com/cuda/nvtiff/userguide.html#decode-api-return-status-codes

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotInitialized

The library handle was not initialized.



InvalidParameter

Wrong parameter was passed. For example, a null pointer as input data, or an invalid enum value.



BadTiff

Cannot parse the TIFF stream. Likely due to a corruption that cannot be handled.



TiffNotSupported

Attempting to decode a TIFF stream that is not supported by the nvTIFF library.



AllocatorFailure

The user-provided allocator functions, for either memory allocation or for releasing the memory, returned a non-zero code.



ExecutionFailed

Error during the execution of the device tasks.



ArchMismatch

The device capabilities are not enough for the set of input parameters provided.



InternalError

Unknown error occured in the library.



NvcompNotFound

nvTiff is unable to load the nvcomp library.



NvjpegNotFound

nvTiff is unable to load the nvjpeg library.



TagNotFound

nvTiff is unable to find information about the provided tag.



ParameterOutOfBounds

Provided parameter is outside the range of possible values.



Nvjpeg2kNotFound

nvTiff is unable to load the nvJPEG2000 library.



BatchIncompatible

Each region in a multi-region decode request is individually decodable, but the requested regions cannot execute as one compatible batch under the current batching rules. Distinct from invalid-parameter and single-image unsupported-image errors.



Other(u32)

A custom (or unimplemented) error that does not fall under any other nvTIFF status error kind.